import boto
import os
import logging

from boto.s3.key import Key
from uuid import uuid4


logger = logging.getLogger(__name__)


class S3FileWriteException(Exception):
  pass


class UserRequestFiles(object):
  def __init__(self, s3_access_key, s3_secret_key, bucket_name):
    self._s3_conn = boto.s3.connection.S3Connection(s3_access_key,
                                                    s3_secret_key,
                                                    is_secure=False)
    self._bucket = self._s3_conn.get_bucket(bucket_name)
    self._prefix = 'userfiles'

  def store_file(self, flask_file):
    file_id = str(uuid4())
    full_key = os.path.join(self._prefix, file_id)
    k = Key(self._bucket, full_key)
    logger.debug('Setting s3 content type to: %s' % flask_file.content_type)
    k.set_metadata('Content-Type', flask_file.content_type)
    bytes_written = k.set_contents_from_file(flask_file)

    if bytes_written == 0:
      raise S3FileWriteException('Unable to write file to S3')

    return file_id

  def get_file_url(self, file_id, expires_in=300):
    full_key = os.path.join(self._prefix, file_id)
    k = Key(self._bucket, full_key)
    return k.generate_url(expires_in)
